package chezmoi

type NullSystem struct {
	emptySystemMixin
	noUpdateSystemMixin
}
